@@ -1,13 +1,11 @@
-import os
 from pathlib import Path
 from uuid import uuid4
 
-import pkg_resources
 import dash_html_components as html
 import dash_core_components as dcc
 from dash.dependencies import Output, Input
-from webviz_config import WebvizPluginABC
-from webviz_config.webviz_assets import WEBVIZ_ASSETS
+from everviz.plugins.plugin_abc import EvervizPluginABC
+
 from everviz.data.load_csv.get_data import get_data
 from everviz.plugins.crossplot.callback.crossplot_callback import (
     get_graph_line,
@@ -20,7 +18,7 @@ from everviz.plugins.crossplot.callback.crossplot_indexed_dropdown import (
 from everviz.plugins.utils.layout.sidebar_layout import get_sidebar_layout
 
 
-class CrossplotIndexed(WebvizPluginABC):
+class CrossplotIndexed(EvervizPluginABC):
     """
     The CrossplotIndexed class implements a plugin for Webviz, which can plot
     any indexed control from the data exported by Everest against any other
@@ -43,10 +41,6 @@ class CrossplotIndexed(WebvizPluginABC):
         self.data_path = data_path
         self.set_callbacks(app)
 
-        ASSETS_DIR = pkg_resources.resource_filename("everviz", os.path.join("assets"))
-
-        WEBVIZ_ASSETS.add(Path(ASSETS_DIR) / "axis_customization.css")
-
     def add_webvizstore(self):
         return [(get_data, [{"data_path": self.data_path}])]
 
@@ -73,8 +67,14 @@ class CrossplotIndexed(WebvizPluginABC):
                     "options": axis_type,
                 },
             ),
-            ("radio", {"item_id": self.axis_options_x_id, "options": axis_options},),
-            ("dropdown", {"item_id": self.dropdown_x_id, "options": dropdown_options},),
+            (
+                "radio",
+                {"item_id": self.axis_options_x_id, "options": axis_options},
+            ),
+            (
+                "dropdown",
+                {"item_id": self.dropdown_x_id, "options": dropdown_options},
+            ),
             (
                 "radio",
                 {
@@ -83,8 +83,14 @@ class CrossplotIndexed(WebvizPluginABC):
                     "options": axis_type,
                 },
             ),
-            ("radio", {"item_id": self.axis_options_y_id, "options": axis_options},),
-            ("dropdown", {"item_id": self.dropdown_y_id, "options": dropdown_options},),
+            (
+                "radio",
+                {"item_id": self.axis_options_y_id, "options": axis_options},
+            ),
+            (
+                "dropdown",
+                {"item_id": self.dropdown_y_id, "options": dropdown_options},
+            ),
             (
                 "radio",
                 {
@@ -136,7 +142,9 @@ class CrossplotIndexed(WebvizPluginABC):
     def set_callbacks(self, app):
         @app.callback(
             Output(self.dropdown_y_id, "options"),
-            [Input(self.dropdown_x_id, "value"),],
+            [
+                Input(self.dropdown_x_id, "value"),
+            ],
         )
         def update_dropwdown_y(selected_control):
             df = get_data(self.data_path)
@@ -144,7 +152,8 @@ class CrossplotIndexed(WebvizPluginABC):
             return dropdown_callback(selected_control, indexed_controls)
 
         @app.callback(
-            Output(self.dropdown_y_id, "value"), [Input(self.dropdown_y_id, "options")],
+            Output(self.dropdown_y_id, "value"),
+            [Input(self.dropdown_y_id, "options")],
         )
         def set_y_val_dropdown(available_options):
             try:
@@ -155,7 +164,7 @@ class CrossplotIndexed(WebvizPluginABC):
         @app.callback(self.plugin_data_output, [self.plugin_data_requested])
         def user_download_data(data_requested):
             if data_requested:
-                return WebvizPluginABC.plugin_data_compress(
+                return EvervizPluginABC.plugin_data_compress(
                     [
                         {
                             "filename": Path(self.data_path).name,
