@@ -1,7 +1,5 @@
 from uuid import uuid4
-from pathlib import Path
 from itertools import cycle
-import pkg_resources
 
 import dash_html_components as html
 import dash_core_components as dcc
@@ -10,15 +8,14 @@ import plotly.graph_objs as go
 from plotly.colors import DEFAULT_PLOTLY_COLORS
 
 from dash.dependencies import Output, Input, State
-from webviz_config import WebvizPluginABC
-from webviz_config.webviz_assets import WEBVIZ_ASSETS
+from everviz.plugins.plugin_abc import EvervizPluginABC
 from everviz.data.load_csv.get_data import get_data
-from everviz.util import parse_range
+from everviz.util import parse_range, get_placeholder_text
 
 from .util import calculate_statistics
 
 
-class ObjectivesPlot(WebvizPluginABC):
+class ObjectivesPlot(EvervizPluginABC):
     """
     The ObjectivesPlot class implements a plugin for Webviz, for plotting the
     objective values generated during an Everest optimization.
@@ -32,20 +29,16 @@ class ObjectivesPlot(WebvizPluginABC):
 
     def __init__(self, app, csv_file):
         super().__init__()
-
         self.graph_id = f"graph-{uuid4()}"
         self.radio_id = f"dropdown-{uuid4()}"
         self.radio_id_mode = f"dropdown-{uuid4()}"
         self.function_dropdown_id = f"dropdown-{uuid4()}"
         self.realization_filter_check_id = f"check-{uuid4()}"
         self.realization_filter_input_id = f"input-{uuid4()}"
-
+        self.label_id = f"label-{uuid4()}"
         self.csv_file = csv_file
         self.set_callbacks(app)
 
-        ASSETS_DIR = Path(pkg_resources.resource_filename("everviz", "assets"))
-        WEBVIZ_ASSETS.add(ASSETS_DIR / "axis_customization.css")
-
     def add_webvizstore(self):
         return [
             (get_data, [{"csv_file": self.csv_file}]),
@@ -57,6 +50,8 @@ class ObjectivesPlot(WebvizPluginABC):
 
         functions = data["function"].unique()
         function_dropdown_options = [{"label": i, "value": i} for i in functions]
+        realizations = data["realization"].unique()
+        placeholder_text = get_placeholder_text(realizations)
         func_elements = [
             html.Label("Functions to plot:"),
             dcc.Dropdown(
@@ -69,6 +64,11 @@ class ObjectivesPlot(WebvizPluginABC):
 
         radio_options = ["Statistics", "Values", "Normalized", "Weighted + Normalized"]
         radio_elements = [
+            html.Label(
+                f"Statistics are calculated based on {len(realizations)} realizations",
+                id=self.label_id,
+                style={"display": "none"},
+            ),
             dcc.RadioItems(
                 id=self.radio_id,
                 options=[{"label": i, "value": i} for i in radio_options],
@@ -99,7 +99,7 @@ class ObjectivesPlot(WebvizPluginABC):
                     dcc.Input(
                         id=self.realization_filter_input_id,
                         type="text",
-                        placeholder="example: 0, 3, 6-10",
+                        placeholder=placeholder_text,
                         pattern=r"\s*|([0-9]+(\s*-\s*[0-9]+)?)(\s*,\s*[0-9]+(\s*-\s*[0-9]+)?)*",
                         style={"display": "inline-block"},
                     ),
@@ -148,7 +148,10 @@ class ObjectivesPlot(WebvizPluginABC):
             ],
         )
         def user_download_data(
-            data_requested, radio_value, realizations_check, realizations_input,
+            data_requested,
+            radio_value,
+            realizations_check,
+            realizations_input,
         ):
             if data_requested:
                 content = get_data(self.csv_file)
@@ -161,8 +164,13 @@ class ObjectivesPlot(WebvizPluginABC):
                     content = calculate_statistics(content)
                 else:
                     filename = "objective_values.csv"
-                return WebvizPluginABC.plugin_data_compress(
-                    [{"filename": filename, "content": content.to_csv(),}]
+                return EvervizPluginABC.plugin_data_compress(
+                    [
+                        {
+                            "filename": filename,
+                            "content": content.to_csv(),
+                        }
+                    ]
                 )
             return ""
 
@@ -173,6 +181,15 @@ class ObjectivesPlot(WebvizPluginABC):
         def set_button_enabled_state(filter_realizations):
             return not filter_realizations
 
+        @app.callback(
+            Output(self.label_id, "style"),
+            [Input(self.radio_id, "value")],
+        )
+        def radio_group_click(option):
+            if option == "Statistics":
+                return {}
+            return {"display": "none"}
+
         @app.callback(
             Output(self.graph_id, "figure"),
             [
@@ -237,7 +254,7 @@ class ObjectivesPlot(WebvizPluginABC):
             return {
                 "data": traces,
                 "layout": dict(
-                    xaxis={"title": "Batch"},
+                    xaxis={"title": "Batch", "tickformat": ",d"},
                     yaxis={"title": "Function Key Value"},
                     hovermode="closest",
                 ),
@@ -266,7 +283,7 @@ def statistics_traces(color, func_data, key, plot_mode):
             showlegend=False,
         ),
         go.Scatter(
-            y=func_data["Mean"],
+            y=func_data["mean"],
             x=func_data["batch"],
             mode=plot_mode,
             marker={"size": 10},
@@ -274,6 +291,26 @@ def statistics_traces(color, func_data, key, plot_mode):
             name=key,
             showlegend=True,
         ),
+        go.Scatter(
+            y=func_data["min_value"],
+            x=func_data["batch"],
+            mode="markers",
+            marker={"size": 10, "symbol": "square"},
+            line={"color": color},
+            name=key,
+            showlegend=False,
+            hovertext=[f"realization: {r}" for r in func_data["min_realization"]],
+        ),
+        go.Scatter(
+            y=func_data["max_value"],
+            x=func_data["batch"],
+            mode="markers",
+            marker={"size": 10, "symbol": "square"},
+            line={"color": color},
+            name=key,
+            showlegend=False,
+            hovertext=[f"realization: {r}" for r in func_data["max_realization"]],
+        ),
     ]
 
 
@@ -307,7 +344,7 @@ def function_traces(
             x=line["batch"],
             mode=mode,
             marker={"size": 10},
-            name=f"{key}_r_{real}",
+            name=f"{key}, r={real}",
             customdata=[real] * len(line["value"]),
             showlegend=True,
             line=line_style,
