@@ -65,19 +65,32 @@ def test_crossplot_layout_radio(dash_duo, expected, placement, valid_options):
 def test_get_sidebar_layout(monkeypatch, mocker):
     radio_mock = mocker.Mock(return_value=[])
     dropdown_mock = mocker.Mock(return_value=[])
+    label_mock = mocker.Mock(return_value=[])
     monkeypatch.setattr(
         everviz.plugins.utils.layout.sidebar_layout, "_get_radio", radio_mock
     )
     monkeypatch.setattr(
-        everviz.plugins.utils.layout.sidebar_layout, "_get_dropdown", dropdown_mock,
+        everviz.plugins.utils.layout.sidebar_layout,
+        "_get_dropdown",
+        dropdown_mock,
+    )
+    monkeypatch.setattr(
+        everviz.plugins.utils.layout.sidebar_layout,
+        "_get_label",
+        label_mock,
     )
 
     get_sidebar_layout(
-        [("radio", {"item_id": "radio_id"}), ("dropdown", {"item_id": "dropdown_id"})]
+        [
+            ("label", {"item_id": "label_id"}),
+            ("radio", {"item_id": "radio_id"}),
+            ("dropdown", {"item_id": "dropdown_id"}),
+        ]
     )
 
     radio_mock.assert_called_once_with(item_id="radio_id")
     dropdown_mock.assert_called_once_with(item_id="dropdown_id")
+    label_mock.assert_called_once_with(item_id="label_id")
 
 
 def test_crossplot_layout(dash_duo, monkeypatch, mocker, tmpdir, assert_equal_images):
@@ -133,9 +146,17 @@ def test_webviz_page_layout(mocker):
         "title": "Cross plots",
         "content": [
             crossplot._crossplot_doc,
-            {"Crossplot": {"data_path": "everest_export.csv",},},
+            {
+                "Crossplot": {
+                    "data_path": "everest_export.csv",
+                },
+            },
             crossplot._crossplot_indexed_doc,
-            {"CrossplotIndexed": {"data_path": "everest_export.csv",}},
+            {
+                "CrossplotIndexed": {
+                    "data_path": "everest_export.csv",
+                }
+            },
         ],
     }
     assert expected_page_layout == result
@@ -150,7 +171,11 @@ def test_webviz_page_layout_no_crossplot(mocker):
         "title": "Cross plots",
         "content": [
             crossplot._crossplot_doc,
-            {"Crossplot": {"data_path": "everest_export.csv",},},
+            {
+                "Crossplot": {
+                    "data_path": "everest_export.csv",
+                },
+            },
         ],
     }
     assert expected_page_layout == result
